@@ -178,16 +178,16 @@ ResultIterator EmailQuery::exec()
         db = Xapian::Database(QFile::encodeName(dir).toStdString());
     } catch (const Xapian::DatabaseOpeningError &) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database does not exist at " << dir;
-        return ResultIterator();
+        return {};
     } catch (const Xapian::DatabaseCorruptError &) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database corrupted";
-        return ResultIterator();
+        return {};
     } catch (const Xapian::DatabaseError &e) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Failed to open Xapian database:" << QString::fromStdString(e.get_description());
-        return ResultIterator();
+        return {};
     } catch (...) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << "Random exception, but we do not want to crash";
-        return ResultIterator();
+        return {};
     }
 
     QList<Xapian::Query> m_queries;
@@ -340,6 +340,6 @@ ResultIterator EmailQuery::exec()
         return iter;
     } catch (const Xapian::Error &e) {
         qCWarning(AKONADI_SEARCH_PIM_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
-        return ResultIterator();
+        return {};
     }
 }
